package com.ruoyi.inventory.service;

import java.util.Date;
import java.util.List;

import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.inventory.domain.HealthcareDrugArchive;
import com.ruoyi.inventory.domain.HealthcareDrugFiling;
import com.ruoyi.inventory.domain.charVo;

/**
 * 药品档案Service接口
 *
<<<<<<< HEAD
 * @author 蒋松霖
=======
 * @author ruoyi
>>>>>>> cf33b39dcb79314a02d35b6116058d8b46856eeb
 * @date 2024-09-19
 */
public interface IHealthcareDrugArchiveService
{
    /**
     * 查询药品档案
     *
     * @param id 药品档案主键
     * @return 药品档案
     */
    public HealthcareDrugArchive selectHealthcareDrugArchiveById(Long id);

    public List<HealthcareDrugArchive> selectHealthcareDrugArchiveByBarcode(String Barcode);

    /**
     * 查询药品档案列表
     *
     * @param healthcareDrugArchive 药品档案
     * @return 药品档案集合
     */
    public List<HealthcareDrugArchive> selectHealthcareDrugArchiveList(HealthcareDrugArchive healthcareDrugArchive);



    /**
     * 新增药品档案
     *
     * @param healthcareDrugArchive 药品档案
     * @return 结果
     */
    public int insertHealthcareDrugArchive(HealthcareDrugArchive healthcareDrugArchive);

    /**
     * 修改药品档案
     *
     * @param healthcareDrugArchive 药品档案
     * @return 结果
     */
    public int updateHealthcareDrugArchive(HealthcareDrugArchive healthcareDrugArchive);

    /**
     * 批量删除药品档案
     *
     * @param ids 需要删除的药品档案主键集合
     * @return 结果
     */
    public int deleteHealthcareDrugArchiveByIds(Long[] ids);

    /**
     * 删除药品档案信息
     *
     * @param id 药品档案主键
     * @return 结果
     */
    public int deleteHealthcareDrugArchiveById(Long id);

    /**
     * 批量新增药品档案
     *
     * @param archiveList 需要删除的数据主键集合
     * @return 结果
     */
    public int insertHealthcareDrugArchives(List<HealthcareDrugArchive> archiveList);

    charVo selectcharMedicine(Date startDate, Date endDate);

    List<HealthcareDrugArchive> selectHealthcareDrugArchiveAdevntList(HealthcareDrugArchive healthcareDrugArchive);

    List<HealthcareDrugArchive> selectHealthcareDrugArchiveAertsList(HealthcareDrugArchive healthcareDrugArchive);
}
